class Topics(object):
    INTERNAL_NOTIFICATION_MESSAGE = 'internal_notification_message'
    SEND_MAIL = 'send_mail'
    SEND_SMS = 'send_sms'
    LOG_MODEL_CHANGES = 'log_model_changes'

    THRIVVE_SEND_SMS = 'thrivve_send_sms'
    THRIVVE_SEND_PUSH_NOTIFICATION = 'thrivve_send_push_notification'
